from setuptools import setup, find_packages

setup(
    name='help_selen',
    version='10',
    packages=find_packages(),
    author='Stefan Mitro',
    author_email='st-mitro@mail.ru',
    url='https://pypi.org/manage/projects/',
)
